==> sqlai_py-0.1.0-py3-none-any.whl: sqlai_py/script1.py <==
import webview
import keyboard
import threading
import time
import ctypes

# Список URL-адресов
urls = [
    "https://chat.qwenlm.ai/",
    "https://chat.mistral.ai/chat",
    "https://chat.deepseek.com/",
    "https://websim.ai/"
]

# Текущая прозрачность (0-255)
current_alpha = 255
hwnd = None

# Функция для изменения прозрачности
def set_transparency(alpha):
    global hwnd, current_alpha
    if hwnd and 30 <= alpha <= 255:
        current_alpha = alpha
        ex_style = ctypes.windll.user32.GetWindowLongW(hwnd, -20)
        ctypes.windll.user32.SetWindowLongW(hwnd, -20, ex_style | 0x80000)
        ctypes.windll.user32.SetLayeredWindowAttributes(hwnd, 0, alpha, 0x02)

def get_hwnd():
    global hwnd
    # Ждать, пока окно появится и будет иметь HWND
    time.sleep(1)
    hwnd = ctypes.windll.user32.FindWindowW(None, "Browser Apps")  # Вероятный заголовок окна PyWebview
    # Если hwnd не найден, используйте другой метод для его определения

def handle_key_press(window):
    global hwnd, current_alpha
    # Ждем получение HWND
    while hwnd is None:
        time.sleep(0.1)
    while True:
        # Уменьшение прозрачности
        if keyboard.is_pressed('alt + z'):
            new_alpha = current_alpha - 5
            set_transparency(new_alpha)
        # Увеличение прозрачности
        elif keyboard.is_pressed('alt + x'):
            new_alpha = current_alpha + 5
            set_transparency(new_alpha)
        # Переключение между URL
        elif keyboard.is_pressed('ctrl + 1'):
            window.load_url(urls[0])
        elif keyboard.is_pressed('ctrl + 2'):
            window.load_url(urls[1])
        elif keyboard.is_pressed('ctrl + 3'):
            window.load_url(urls[2])
        elif keyboard.is_pressed('ctrl + 4'):
            window.load_url(urls[3])
        # Скрытие окна
        elif keyboard.is_pressed('ctrl + alt + q'):
            ctypes.windll.user32.ShowWindow(hwnd, 0)  # SW_HIDE
        # Отображение окна
        elif keyboard.is_pressed('ctrl + alt + w'):
            ctypes.windll.user32.ShowWindow(hwnd, 1)  # SW_SHOWNORMAL
        # Ограничение значения прозрачности
        if current_alpha < 30:
            set_transparency(30)
        elif current_alpha > 255:
            set_transparency(255)

def main():
    global hwnd
    # Создание окна с веб-страницей
    window = webview.create_window("Browser Apps", urls[0], width=800, height=600)
    
    # Скрываем окно сразу после создания
    def hide_window():
        global hwnd
        time.sleep(1)  # Ждем, пока окно появится
        hwnd = ctypes.windll.user32.FindWindowW(None, "Browser Apps")
        if hwnd:
            ctypes.windll.user32.ShowWindow(hwnd, 0)  # SW_HIDE
    
    hide_thread = threading.Thread(target=hide_window)
    hide_thread.start()
    
    # Запуск потока получения HWND
    thread_hwnd = threading.Thread(target=get_hwnd)
    thread_hwnd.start()
    
    # Запуск потока обработки клавиш
    thread_key_press = threading.Thread(target=handle_key_press, args=(window,))
    thread_key_press.daemon = True
    thread_key_press.start()
    
    webview.start()

if __name__ == "__main__":
    main()

==> sqlai_py-0.1.1-py3-none-any.whl: sqlai_py/script1.py <==
import webview
import keyboard
import threading
import time
import ctypes

# Список URL-адресов
urls = [
    "https://chat.qwenlm.ai/",
    "https://chat.mistral.ai/chat",
    "https://chat.deepseek.com/",
    "https://websim.ai/",
    "https://witty-shoe-5361.puter.site/"
]

# Текущая прозрачность (0-255)
current_alpha = 255
hwnd = None

# Функция для изменения прозрачности
def set_transparency(alpha):
    global hwnd, current_alpha
    if hwnd and 30 <= alpha <= 255:
        current_alpha = alpha
        ex_style = ctypes.windll.user32.GetWindowLongW(hwnd, -20)
        ctypes.windll.user32.SetWindowLongW(hwnd, -20, ex_style | 0x80000)
        ctypes.windll.user32.SetLayeredWindowAttributes(hwnd, 0, alpha, 0x02)

def get_hwnd():
    global hwnd
    # Ждать, пока окно появится и будет иметь HWND
    time.sleep(1)
    hwnd = ctypes.windll.user32.FindWindowW(None, "Browser Apps")  # Вероятный заголовок окна PyWebview
    # Если hwnd не найден, используйте другой метод для его определения

def handle_key_press(window):
    global hwnd, current_alpha
    # Ждем получение HWND
    while hwnd is None:
        time.sleep(0.1)
    while True:
        # Уменьшение прозрачности
        if keyboard.is_pressed('alt + z'):
            new_alpha = current_alpha - 5
            set_transparency(new_alpha)
        # Увеличение прозрачности
        elif keyboard.is_pressed('alt + x'):
            new_alpha = current_alpha + 5
            set_transparency(new_alpha)
        # Переключение между URL
        elif keyboard.is_pressed('ctrl + 1'):
            window.load_url(urls[0])
        elif keyboard.is_pressed('ctrl + 2'):
            window.load_url(urls[1])
        elif keyboard.is_pressed('ctrl + 3'):
            window.load_url(urls[2])
        elif keyboard.is_pressed('ctrl + 4'):
            window.load_url(urls[3])
        elif keyboard.is_pressed('ctrl + 5'):
            window.load_url(urls[4])
        # Скрытие окна
        elif keyboard.is_pressed('ctrl + alt + q'):
            ctypes.windll.user32.ShowWindow(hwnd, 0)  # SW_HIDE
        # Отображение окна
        elif keyboard.is_pressed('ctrl + alt + w'):
            ctypes.windll.user32.ShowWindow(hwnd, 1)  # SW_SHOWNORMAL
        # Ограничение значения прозрачности
        if current_alpha < 30:
            set_transparency(30)
        elif current_alpha > 255:
            set_transparency(255)

def main():
    global hwnd
    # Создание окна с веб-страницей
    window = webview.create_window("Browser Apps", urls[0], width=800, height=600)
    
    # Скрываем окно сразу после создания
    def hide_window():
        global hwnd
        time.sleep(1)  # Ждем, пока окно появится
        hwnd = ctypes.windll.user32.FindWindowW(None, "Browser Apps")
        if hwnd:
            ctypes.windll.user32.ShowWindow(hwnd, 0)  # SW_HIDE
    
    hide_thread = threading.Thread(target=hide_window)
    hide_thread.start()
    
    # Запуск потока получения HWND
    thread_hwnd = threading.Thread(target=get_hwnd)
    thread_hwnd.start()
    
    # Запуск потока обработки клавиш
    thread_key_press = threading.Thread(target=handle_key_press, args=(window,))
    thread_key_press.daemon = True
    thread_key_press.start()
    
    webview.start()

if __name__ == "__main__":
    main()
